@@ -39,6 +39,7 @@
 #include "clang/AST/TemplateName.h"
 #include "clang/AST/Type.h"
 #include "clang/AST/TypeLoc.h"
+#include "clang/Basic/Builtins.h"
 #include "clang/Basic/SourceLocation.h"
 #include "clang/Basic/SourceManager.h"
 
@@ -424,10 +425,6 @@ string PrintableLoc(SourceLocation loc) {
   }
 }
 
-string PrintableSourceRange(SourceRange range) {
-  return PrintableLoc(range.getBegin()) + " - " + PrintableLoc(range.getEnd());
-}
-
 string PrintableDecl(const Decl* decl, bool terse/*=true*/) {
   // Use the terse flag to limit the level of output to one line.
   clang::PrintingPolicy policy = decl->getASTContext().getPrintingPolicy();
@@ -922,7 +919,7 @@ bool IsDefaultNewOrDelete(const FunctionDecl* decl,
                           const string& decl_loc_as_quoted_include) {
   // Clang will report <new> as the location of the default new and
   // delete operators if <new> is included. Otherwise, it reports the
-  // (fake) file "<built_in>".
+  // (fake) file "<built-in>".
   if (decl_loc_as_quoted_include != "<new>" &&
       !IsBuiltinFile(GetFileEntry(decl)))
     return false;
@@ -1083,6 +1080,15 @@ bool DeclsAreInSameClass(const Decl* decl1, const Decl* decl2) {
   return decl1->getDeclContext()->isRecord();
 }
 
+bool IsBuiltinFunction(const clang::NamedDecl* decl,
+                       const std::string& symbol_name) {
+  if (const clang::IdentifierInfo* iden = decl->getIdentifier()) {
+    return iden->getBuiltinID() != 0 &&
+           !clang::Builtin::Context::isBuiltinFunc(symbol_name.c_str());
+  }
+  return false;
+}
+
 // --- Utilities for Type.
 
 const Type* GetTypeOf(const Expr* expr) {
@@ -1393,15 +1399,6 @@ const FunctionType* GetCalleeFunctionType(CallExpr* expr) {
   return callee_type->getAs<FunctionType>();
 }
 
-bool IsCastToReferenceType(const CastExpr* expr) {
-  if (const ExplicitCastExpr* explicit_cast = DynCastFrom(expr)) {
-    return explicit_cast->getTypeAsWritten()->isReferenceType();
-  } else if (const ImplicitCastExpr* implicit_cast = DynCastFrom(expr)) {
-    return implicit_cast->getValueKind() == clang::VK_LValue;
-  }
-  CHECK_UNREACHABLE_("Unexpected type of cast expression");
-}
-
 TemplateArgumentListInfo GetExplicitTplArgs(const Expr* expr) {
   TemplateArgumentListInfo explicit_tpl_args;
   if (const DeclRefExpr* decl_ref = DynCastFrom(expr))
