@@ -428,7 +428,6 @@ const clang::DeclContext* GetDeclContext(const ASTNode* ast_node);
 // --- Printers.
 
 string PrintableLoc(clang::SourceLocation loc);
-string PrintableSourceRange(clang::SourceRange range);
 string PrintableDecl(const clang::Decl* decl, bool terse=true);
 string PrintableStmt(const clang::Stmt* stmt);
 string PrintableType(const clang::Type* type);
@@ -656,6 +655,10 @@ const clang::NamedDecl* GetNonfriendClassRedecl(const clang::NamedDecl* decl);
 // same, and it's a class (or struct).
 bool DeclsAreInSameClass(const clang::Decl* decl1, const clang::Decl* decl2);
 
+// Returns true if the given decl/name is a builtin function
+bool IsBuiltinFunction(const clang::NamedDecl* decl,
+                       const std::string& symbol_name);
+
 // --- Utilities for Type.
 
 const clang::Type* GetTypeOf(const clang::Expr* expr);
@@ -799,12 +802,6 @@ const clang::CXXDestructorDecl* GetSiblingDestructorFor(
 // Should never return nullptr.
 const clang::FunctionType* GetCalleeFunctionType(clang::CallExpr* expr);
 
-// Figuring out whether the to-type is a reference or not is different
-// depending on whether the cast is explicit or implicit.  (You'd
-// think it would work to just look at expr->getSubExpr()->getType(),
-// but that seems to strip off the reference.)
-bool IsCastToReferenceType(const clang::CastExpr* expr);
-
 // Returns the list of explicit template args for all exprs that support
 // such a concept (declrefexpr, memberexpr), and empty list if none is present.
 clang::TemplateArgumentListInfo GetExplicitTplArgs(const clang::Expr* expr);
