@@ -62,10 +62,9 @@ static void PrintHelp(const char* extra_msg) {
          "        to the default of reporting for the input .cc file and its\n"
          "        associated .h files).  This flag may be specified multiple\n"
          "        times to specify multiple glob patterns.\n"
-         "   --cwd=<dir>: tells iwyu what the current working directory is.\n"
-         "   --howtodebug[=<filename>]: with no arg, prints instructions on\n"
-         "        how to run iwyu under gdb for the input file, and exits.\n"
-         "        With an arg, prints only when input file matches the arg.\n"
+         "   --keep=<glob>: tells iwyu to always keep these includes.\n"
+         "        This flag may be specified multiple times to specify\n"
+         "        multiple glob patterns.\n"
          "   --mapping_file=<filename>: gives iwyu a mapping file.\n"
          "   --no_default_mappings: do not add iwyu's default mappings.\n"
          "   --pch_in_code: mark the first include in a translation unit as a\n"
@@ -96,6 +95,7 @@ static void PrintHelp(const char* extra_msg) {
          "   --verbose=<level>: the higher the level, the more output.\n"
          "   --quoted_includes_first: when sorting includes, place quoted\n"
          "        ones first.\n"
+         "   --cxx17ns: suggests the more concise syntax introduced in C++17\n"
          "\n"
          "In addition to IWYU-specific options you can specify the following\n"
          "options without -Xiwyu prefix:\n"
@@ -156,8 +156,7 @@ OptionsParser::~OptionsParser() {
 }
 
 CommandlineFlags::CommandlineFlags()
-    : howtodebug(CommandlineFlags::kUnspecified),
-      transitive_includes_only(false),
+    : transitive_includes_only(false),
       verbose(getenv("IWYU_VERBOSE") ? atoi(getenv("IWYU_VERBOSE")) : 1),
       no_default_mappings(false),
       max_line_length(80),
@@ -165,32 +164,32 @@ CommandlineFlags::CommandlineFlags()
       pch_in_code(false),
       no_comments(false),
       no_fwd_decls(false),
-      quoted_includes_first(false) {
+      quoted_includes_first(false),
+      cxx17ns(false) {
 }
 
 int CommandlineFlags::ParseArgv(int argc, char** argv) {
   static const struct option longopts[] = {
     {"check_also", required_argument, nullptr, 'c'},  // can be specified >once
-    {"howtodebug", optional_argument, nullptr, 'd'},
-    {"cwd", required_argument, nullptr, 'p'},
+    {"keep", required_argument, nullptr, 'k'},  // can be specified >once
     {"transitive_includes_only", no_argument, nullptr, 't'},
     {"verbose", required_argument, nullptr, 'v'},
     {"mapping_file", required_argument, nullptr, 'm'},
     {"no_default_mappings", no_argument, nullptr, 'n'},
     {"prefix_header_includes", required_argument, nullptr, 'x'},
     {"pch_in_code", no_argument, nullptr, 'h'},
-    {"max_line_length", optional_argument, nullptr, 'l'},
-    {"no_comments", optional_argument, nullptr, 'o'},
-    {"no_fwd_decls", optional_argument, nullptr, 'f'},
+    {"max_line_length", required_argument, nullptr, 'l'},
+    {"no_comments", no_argument, nullptr, 'o'},
+    {"no_fwd_decls", no_argument, nullptr, 'f'},
     {"quoted_includes_first", no_argument, nullptr, 'q' },
+    {"cxx17ns", no_argument, nullptr, 'C'},
     {nullptr, 0, nullptr, 0}
   };
-  static const char shortopts[] = "d::p:v:c:m:n";
+  static const char shortopts[] = "v:c:m:n";
   while (true) {
     switch (getopt_long(argc, argv, shortopts, longopts, nullptr)) {
       case 'c': AddGlobToReportIWYUViolationsFor(optarg); break;
-      case 'd': howtodebug = optarg ? optarg : ""; break;
-      case 'p': cwd = optarg; break;
+      case 'k': AddGlobToKeepIncludes(optarg); break;
       case 't': transitive_includes_only = true; break;
       case 'v': verbose = atoi(optarg); break;
       case 'm': mapping_files.push_back(optarg); break;
@@ -215,6 +214,7 @@ int CommandlineFlags::ParseArgv(int argc, char** argv) {
         CHECK_((max_line_length >= 0) && "Max line length must be positive");
         break;
       case 'q': quoted_includes_first = true; break;
+      case 'C': cxx17ns = true; break;
       case -1: return optind;   // means 'no more input'
       default:
         PrintHelp("FATAL ERROR: unknown flag.");
@@ -251,11 +251,6 @@ static int ParseInterceptedCommandlineFlags(int argc, char** argv) {
   return optind;  // unreachable
 }
 
-// The default value for the --howtodebug flag.  Indicates that the
-// flag isn't present.  It's a special, reserved value, and a user
-// isn't expected to type it directly.
-const char CommandlineFlags::kUnspecified[] = "<flag-unspecified>";
-
 // Handles all iwyu-specific flags, like --verbose.  Returns the index into
 // argv past all the iwyu commandline flags.
 static int ParseIwyuCommandlineFlags(int argc, char** argv) {
@@ -264,15 +259,6 @@ static int ParseIwyuCommandlineFlags(int argc, char** argv) {
   const int retval = commandline_flags->ParseArgv(argc, argv);
   SetVerboseLevel(commandline_flags->verbose);
 
-  if (!commandline_flags->cwd.empty()) {
-    printf("-p/--cwd not yet implemented\n");
-    exit(EXIT_INVALIDARGS);
-  }
-  if (commandline_flags->howtodebug != CommandlineFlags::kUnspecified) {
-    printf("-d/--howtodebug not yet implemented\n");
-    exit(EXIT_INVALIDARGS);
-  }
-
   VERRS(4) << "Setting verbose-level to " << commandline_flags->verbose << "\n";
 
   return retval;
@@ -401,6 +387,21 @@ bool ShouldReportIWYUViolationsFor(const clang::FileEntry* file) {
   return false;
 }
 
+void AddGlobToKeepIncludes(const string& glob) {
+  CHECK_(commandline_flags && "Call ParseIwyuCommandlineFlags() before this");
+  commandline_flags->keep.insert(NormalizeFilePath(glob));
+}
+
+bool ShouldKeepIncludeFor(const clang::FileEntry* file) {
+  if (GlobalFlags().keep.empty())
+    return false;
+  const string filepath = GetFilePath(file);
+  for (const string& glob : GlobalFlags().keep)
+    if (GlobMatchesPath(glob.c_str(), filepath.c_str()))
+      return true;
+  return false;
+}
+
 void InitGlobalsAndFlagsForTesting() {
   CHECK_(commandline_flags == nullptr && "Only parse commandline flags once");
   CHECK_(include_picker == nullptr && "Only call InitGlobals[ForTesting] once");
