@@ -96,6 +96,8 @@ const IncludeMapEntry libc_symbol_map[] = {
   { "blkcnt_t", kPrivate, "<sys/stat.h>", kPublic },
   { "blkcnt_t", kPrivate, "<sys/types.h>", kPublic },
   { "blksize_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "clock_t", kPrivate, "<sys/types.h>", kPublic },
+  { "clock_t", kPrivate, "<time.h>", kPublic },
   { "daddr_t", kPrivate, "<sys/types.h>", kPublic },
   { "daddr_t", kPrivate, "<rpc/types.h>", kPublic },
   { "dev_t", kPrivate, "<sys/types.h>", kPublic },
@@ -123,7 +125,15 @@ const IncludeMapEntry libc_symbol_map[] = {
   { "ino_t", kPrivate, "<sys/stat.h>", kPublic },
   { "int8_t", kPrivate, "<sys/types.h>", kPublic },
   { "int8_t", kPrivate, "<stdint.h>", kPublic },
+  { "int16_t", kPrivate, "<stdint.h>", kPublic },
+  { "int32_t", kPrivate, "<stdint.h>", kPublic },
+  { "int64_t", kPrivate, "<stdint.h>", kPublic },
+  { "uint8_t", kPrivate, "<stdint.h>", kPublic },
+  { "uint16_t", kPrivate, "<stdint.h>", kPublic },
+  { "uint32_t", kPrivate, "<stdint.h>", kPublic },
+  { "uint64_t", kPrivate, "<stdint.h>", kPublic },
   { "intptr_t", kPrivate, "<stdint.h>", kPublic },
+  { "uintptr_t", kPrivate, "<stdint.h>", kPublic },
   { "intptr_t", kPrivate, "<unistd.h>", kPublic },
   { "key_t", kPrivate, "<sys/types.h>", kPublic },
   { "key_t", kPrivate, "<sys/ipc.h>", kPublic },
@@ -160,6 +170,10 @@ const IncludeMapEntry libc_symbol_map[] = {
   { "suseconds_t", kPrivate, "<sys/types.h>", kPublic },
   { "suseconds_t", kPrivate, "<sys/time.h>", kPublic },
   { "suseconds_t", kPrivate, "<sys/select.h>", kPublic },
+  { "time_t", kPrivate, "<sys/types.h>", kPublic },
+  { "time_t", kPrivate, "<time.h>", kPublic },
+  { "timespec", kPrivate, "<time.h>", kPublic },
+  { "timeval", kPrivate, "<sys/time.h>", kPublic },
   { "u_char", kPrivate, "<sys/types.h>", kPublic },
   { "u_char", kPrivate, "<rpc/types.h>", kPublic },
   { "uid_t", kPrivate, "<sys/types.h>", kPublic },
@@ -899,14 +913,9 @@ void MakeNodeTransitive(IncludePicker::IncludeMap* filename_map,
   // If we've already calculated this node's transitive closure, we're done.
   const TransitiveStatus status = (*seen_nodes)[key];
   if (status == kCalculating) {   // means there's a cycle in the mapping
-    // third-party code sometimes has #include cycles (*cough* boost
-    // *cough*).  Because we add many implicit third-party mappings,
-    // we may add a cycle without meaning to.  The best we can do is
-    // to ignore the mapping that causes the cycle.  Same with code
-    // in /internal/.  We could CHECK-fail in such a case, but it's
-    // probably better to just keep going.
-    if (StartsWith(key, "\"third_party/") ||
-        key.find("internal/") != string::npos) {
+    // TODO: Reconsider cycle handling; the include_cycle test fails without
+    // this special-casing, but it seems we should handle this more generally.
+    if (key.find("internal/") != string::npos) {
       VERRS(4) << "Ignoring a cyclical mapping involving " << key << "\n";
       return;
     }
@@ -1229,58 +1238,6 @@ void IncludePicker::ExpandRegexes() {
   }
 }
 
-// We treat third-party code specially, since it's difficult to add
-// iwyu pragmas to code we don't own.  Basically, what we do is trust
-// the code authors when it comes to third-party code: if they
-// #include x.h to get symbols from y.h, then assume that's how the
-// third-party authors wanted it.  This boils down to the following
-// rules:
-// 1) If there's already a mapping for third_party/y.h, do not
-//    add any implicit maps for it.
-// 2) if not_third_party/x.{h,cc} #includes third_party/y.h,
-//    assume y.h is supposed to be included directly, and do not
-//    add any implicit maps for it.
-// 3) Otherwise, if third_party/x.h #includes third_party/y.h,
-//    add a mapping from y.h to x.h.  Unless y.h already has
-//    a hard-coded visibility set, make y.h private.  This
-//    means iwyu will never suggest adding y.h.
-void IncludePicker::AddImplicitThirdPartyMappings() {
-  set<string> third_party_headers_with_explicit_mappings;
-  for (const IncludeMap::value_type& item : filepath_include_map_) {
-    if (IsThirdPartyFile(item.first))
-      third_party_headers_with_explicit_mappings.insert(item.first);
-  }
-
-  set<string> headers_included_from_non_third_party;
-  for (const auto& incmap : quoted_includes_to_quoted_includers_) {
-    for (const string& includer : incmap.second) {
-      if (!IsThirdPartyFile(includer)) {
-        headers_included_from_non_third_party.insert(incmap.first);
-        break;
-      }
-    }
-  }
-
-  for (const auto& incmap : quoted_includes_to_quoted_includers_) {
-    const string& includee = incmap.first;
-    if (!IsThirdPartyFile(includee) ||
-        ContainsKey(third_party_headers_with_explicit_mappings, includee) ||
-        ContainsKey(headers_included_from_non_third_party, includee)) {
-      continue;
-    }
-    for (const string& includer : incmap.second) {
-      // From the 'if' statement above, we already know that includee
-      // is not included from non-third-party code.
-      CHECK_(IsThirdPartyFile(includer) && "Why not nixed!");
-      CHECK_(IsThirdPartyFile(includee) && "Why not nixed!");
-      AddMapping(includee, includer);
-      if (GetVisibility(includee) == kUnusedVisibility) {
-        MarkIncludeAsPrivate(includee);
-      }
-    }
-  }
-}
-
 // Handle work that's best done after we've seen all the mappings
 // (including dynamically-added ones) and all the include files.
 // For instance, we can now expand all the regexes we've seen in
@@ -1293,10 +1250,6 @@ void IncludePicker::FinalizeAddedIncludes() {
   // Match those to seen #includes now.
   ExpandRegexes();
 
-  // We treat third-party code specially, since it's difficult to add
-  // iwyu pragmas to code we don't own.
-  AddImplicitThirdPartyMappings();
-
   // If a.h maps to b.h maps to c.h, we'd like an entry from a.h to c.h too.
   MakeMapTransitive(&filepath_include_map_);
   // Now that filepath_include_map_ is transitively closed, it's an
