@@ -346,12 +346,27 @@ string PrintablePtr(const void* ptr) {
 //       `-- TagDecl           (class, struct, union, enum)
 //           `-- RecordDecl    (class, struct, union)
 
+// Determines if a NamedDecl has any parent namespace, which is anonymous.
+bool HasAnonymousNamespace(const NamedDecl* decl) {
+  for (const DeclContext* ctx = decl->getDeclContext();
+       ctx && isa<NamedDecl>(ctx); ctx = ctx->getParent()) {
+    if (const NamespaceDecl* ns = DynCastFrom(ctx)) {
+      if (ns->isAnonymousNamespace()) {
+        return true;
+      }
+    }
+  }
+
+  return false;
+}
+
 // Given a NamedDecl that presents a (possibly template) record
 // (i.e. class, struct, or union) type declaration, and the print-out
 // of its (possible) template parameters and kind (e.g. "template
 // <typename T> struct"), returns its forward declaration line.
 string PrintForwardDeclare(const NamedDecl* decl,
-                           const string& tpl_params_and_kind) {
+                           const string& tpl_params_and_kind,
+                           bool cxx17ns) {
   // We need to short-circuit the logic for testing.
   if (const FakeNamedDecl* fake = FakeNamedDeclIfItIsOne(decl)) {
     return tpl_params_and_kind + " " + fake->qual_name() + ";";
@@ -362,19 +377,39 @@ string PrintForwardDeclare(const NamedDecl* decl,
 
   std::string fwd_decl = std::string(decl->getName()) + ";";
   bool seen_namespace = false;
+  // Anonymous namespaces are not using the more concise syntax.
+  bool concat_namespaces = cxx17ns && !HasAnonymousNamespace(decl);
   for (const DeclContext* ctx = decl->getDeclContext();
        ctx && isa<NamedDecl>(ctx); ctx = ctx->getParent()) {
     if (const RecordDecl* rec = DynCastFrom(ctx)) {
       fwd_decl = std::string(rec->getName()) + "::" + fwd_decl;
     } else if (const NamespaceDecl* ns = DynCastFrom(ctx)) {
+      bool first = !seen_namespace;
       if (!seen_namespace) {
         seen_namespace = true;
         fwd_decl = tpl_params_and_kind + " " + fwd_decl;
       }
 
-      const std::string ns_name = ns->isAnonymousNamespace() ?
-          "" : (std::string(ns->getName()) + " ");
-      fwd_decl = "namespace " + ns_name + "{ " + fwd_decl + " }";
+      if (concat_namespaces) {
+        std::string ns_name = std::string(ns->getName());
+        std::string prefix = ns_name;
+        std::string suffix;
+        if (first) {
+          first = false;
+          prefix = prefix + " { ";
+        }
+        if (ctx->getParent() && isa<NamedDecl>(ctx->getParent())) {
+          prefix = "::" + prefix;
+        } else {
+          prefix = "namespace " + prefix;
+          suffix = " }";
+        }
+        fwd_decl = prefix + fwd_decl + suffix;
+      } else {
+        std::string ns_name = ns->isAnonymousNamespace() ?
+            std::string() : (std::string(ns->getName()) + " ");
+        fwd_decl = "namespace " + ns_name + "{ " + fwd_decl + " }";
+      }
     } else if (const FunctionDecl* fn = DynCastFrom(ctx)) {
       // A local class (class defined inside a function).
       fwd_decl = std::string(fn->getName()) + "::" + fwd_decl;
@@ -392,7 +427,7 @@ string PrintForwardDeclare(const NamedDecl* decl,
 // Given a RecordDecl, return the line that could be put in source
 // code to forward-declare the record type, e.g. "namespace ns { class Foo; }".
 string MungedForwardDeclareLineForNontemplates(const RecordDecl* decl) {
-  return PrintForwardDeclare(decl, GetKindName(decl));
+  return PrintForwardDeclare(decl, GetKindName(decl), GlobalFlags().cxx17ns);
 }
 
 // Given a TemplateDecl representing a class|struct|union template
@@ -421,7 +456,7 @@ string MungedForwardDeclareLineForTemplates(const TemplateDecl* decl) {
   // argument is inclusive, so substract one to get past the end-space.
   const string::size_type name = line.rfind(' ', endpos - 1);
   CHECK_(name != string::npos && "Unexpected printable template-type");
-  return PrintForwardDeclare(decl, line.substr(0, name));
+  return PrintForwardDeclare(decl, line.substr(0, name), GlobalFlags().cxx17ns);
 }
 
 string MungedForwardDeclareLine(const NamedDecl* decl) {
@@ -728,6 +763,7 @@ bool DeclIsVisibleToUseInSameFile(const Decl* decl, const OneUse& use) {
 // files.  For everything but foo.cc, this is empty; for foo.cc it's
 // foo.h's includes and foo-inl.h's includes.
 set<string> CalculateMinimalIncludes(
+    const string& use_quoted_include,
     const set<string>& direct_includes,
     const set<string>& associated_direct_includes,
     vector<OneUse>* uses) {
@@ -754,8 +790,10 @@ set<string> CalculateMinimalIncludes(
     // this is a file that the use-file is re-exporting symbols for,
     // and we should keep the #include as-is.
     const string use_file = ConvertToQuotedInclude(GetFilePath(use.use_loc()));
-    if (use.PublicHeadersContain(use_file)) {
-      use.set_suggested_header(ConvertToQuotedInclude(use.decl_filepath()));
+    const string decl_file = ConvertToQuotedInclude(use.decl_filepath());
+    if (use.PublicHeadersContain(use_file) &&
+        ContainsKey(direct_includes, decl_file)) {
+      use.set_suggested_header(decl_file);
       desired_headers.insert(use.suggested_header());
       LogIncludeMapping("private header", use);
     } else if (use.public_headers().size() == 1) {
@@ -766,18 +804,29 @@ set<string> CalculateMinimalIncludes(
   }
 
   // Steps (2): Go through the needed private-includes that map to
-  // more than one public #include.  First choice: an include in
-  // associated_direct_includes (those are includes that are not going
-  // away, since we can't change associated files).  Second choice,
-  // includes in direct_includes that are also already in
-  // desired_headers.  Third choice, includes in desired_headers.
-  // Fourth choice, includes in direct_includes.  Picking in
-  // this order minimizes the number of #includes we add, while
-  // allowing us to remove #includes if need be.
+  // more than one public #include.  Use the following priority order:
+  // - Ourselves.
+  // - An include in associated_direct_includes (those are includes
+  //   that are not going away, since we can't change associated
+  //   files).
+  // - Includes in direct_includes that are also already in
+  //   desired_headers.
+  // - Includes in desired_headers.
+  // - Includes in direct_includes.
+  // Picking in this order minimizes the number of #includes we add,
+  // while allowing us to remove #includes if need be.
   for (OneUse& use : *uses) {
     if (!use.NeedsSuggestedHeader())
       continue;
     const vector<string>& public_headers = use.public_headers();
+    for (const string& choice : public_headers) {
+      if (use.has_suggested_header())
+        break;
+      if (choice == use_quoted_include) {
+        use.set_suggested_header(choice);
+        LogIncludeMapping("in self", use);
+      }
+    }
     // TODO(csilvers): write ElementInBoth() in iwyu_stl_util.h
     for (const string& choice : public_headers) {
       if (use.has_suggested_header())
@@ -950,7 +999,9 @@ set<string> CalculateMinimalIncludes(
 // Calculate IWYU violations for full uses:
 // E1) Sanity check: ignore the use if it would require adding an
 //     #include of a .cc file.
-// E2) If the desired include-file for this symbols is not in the
+// E2) Ignore use when the suggested header *is* the current file
+//     (this can happen due to mappings).
+// E3) If the desired include-file for this symbols is not in the
 //     current includes, mark as an iwyu violation.
 
 void ProcessForwardDeclare(OneUse* use,
@@ -1054,12 +1105,21 @@ void ProcessForwardDeclare(OneUse* use,
     }
   }
 
-  // (A7) If --no_fwd_decls has been passed, recategorize as a full use.
-  if (GlobalFlags().no_fwd_decls) {
+  // (A7) If --no_fwd_decls has been passed, recategorize as a full use unless
+  // the decl is in this file (in which case it must be a self-sufficient decl
+  // being used, so we can just let IWYU do its work).
+  if (!use->ignore_use() &&
+      GlobalFlags().no_fwd_decls &&
+      GetFileEntry(use->decl_loc()) != GetFileEntry(use->use_loc())) {
     use->set_full_use();
   }
 }
 
+// Returns true if the given symbol has a mapping defined to a file.
+static bool HasMapping(const string& symbol) {
+  return !GlobalIncludePicker().GetCandidateHeadersForSymbol(symbol).empty();
+}
+
 void ProcessFullUse(OneUse* use,
                     const IwyuPreprocessorInfo* preprocessor_info) {
   CHECK_(use->decl() && "Must call ProcessFullUse on a decl");
@@ -1067,6 +1127,14 @@ void ProcessFullUse(OneUse* use,
   if (use->ignore_use())   // we're already ignoring it
     return;
 
+  // We normally ignore uses for builtins, but when there is a mapping defined
+  // for the symbol, we should respect that.  So, we need to determine whether
+  // the symbol has any mappings.
+  bool is_builtin_function = IsBuiltinFunction(use->decl(), use->symbol_name());
+
+  bool is_builtin_function_with_mappings =
+      is_builtin_function && HasMapping(use->symbol_name());
+
   // (B1) If the definition is after the use, re-point to a prior decl.
   // If iwyu followed the language precisely, this wouldn't be
   // necessary: code wouldn't compile if a full-use didn't have the
@@ -1111,7 +1179,7 @@ void ProcessFullUse(OneUse* use,
   // All this is moot when FunctionDecls are being defined, all their redecls
   // are separately registered as uses so that a definition anchors all its
   // declarations.
-  if (!use->is_function_being_defined()) {
+  if (!use->is_function_being_defined() && !is_builtin_function_with_mappings) {
     set<const NamedDecl*> all_redecls;
     if (isa<RecordDecl>(use->decl()) || isa<ClassTemplateDecl>(use->decl()))
       all_redecls.insert(use->decl());  // for classes, just consider the dfn
@@ -1137,14 +1205,11 @@ void ProcessFullUse(OneUse* use,
     return;
   }
   // A compiler builtin without a predefined header file (e.g. __builtin_..)
-  if (const clang::IdentifierInfo* iden = use->decl()->getIdentifier()) {
-    if (iden->getBuiltinID() != 0 &&
-        !clang::Builtin::Context::isBuiltinFunc(use->symbol_name().c_str())) {
-      VERRS(6) << "Ignoring use of " << use->symbol_name()
-               << " (" << use->PrintableUseLoc() << "): built-in function\n";
-      use->set_ignore_use();
-      return;
-    }
+  if (is_builtin_function && !is_builtin_function_with_mappings) {
+    VERRS(6) << "Ignoring use of " << use->symbol_name()
+             << " (" << use->PrintableUseLoc() << "): built-in function\n";
+    use->set_ignore_use();
+    return;
   }
   // Special case for operators new/delete: Only treated as built-in if they
   // are the default, non-placement versions.
@@ -1206,7 +1271,8 @@ void ProcessFullUse(OneUse* use,
   // the language requires).
   // TODO(csilvers): remove this when we resolve the bugs with macros/typedefs.
   if (preprocessor_info->FileTransitivelyIncludes(
-          GetFileEntry(use->decl()), GetFileEntry(use->use_loc()))) {
+          GetFileEntry(use->decl()), GetFileEntry(use->use_loc())) &&
+      !is_builtin_function_with_mappings) {
     VERRS(6) << "Ignoring use of " << use->symbol_name()
              << " (" << use->PrintableUseLoc() << "): 'backwards' #include\n";
     use->set_ignore_use();
@@ -1390,7 +1456,8 @@ void CalculateIwyuForForwardDeclareUse(
 }
 
 void CalculateIwyuForFullUse(OneUse* use,
-                             const set<string>& actual_includes) {
+                             const set<string>& actual_includes,
+                             const string& use_quoted_include) {
   CHECK_(!use->ignore_use() && "Trying to calculate on an ignored use");
   CHECK_(use->is_full_use() && "CalculateIwyuForFullUse requires a full use");
   CHECK_(use->has_suggested_header() && "All full uses must have a header");
@@ -1435,7 +1502,18 @@ void CalculateIwyuForFullUse(OneUse* use,
     return;
   }
 
-  // (E2) Mark iwyu violation unless in a current #include.
+  // (E2) Ignore use when the suggested header *is* the current file (this can
+  // happen due to mappings).
+  if (use_quoted_include == use->suggested_header()) {
+    VERRS(6) << "Ignoring full use of " << use->symbol_name()
+             << " (" << use->PrintableUseLoc()
+             << "): use already in suggested header "
+             << use->suggested_header() << "\n";
+    use->set_ignore_use();
+    return;
+  }
+
+  // (E3) Mark iwyu violation unless in a current #include.
   if (ContainsKey(actual_includes, use->suggested_header())) {
     VERRS(6) << "Ignoring full use of " << use->symbol_name()
              << " (" << use->PrintableUseLoc() << "): #including dfn from "
@@ -1481,7 +1559,7 @@ void IwyuFileInfo::CalculateIwyuViolations(vector<OneUse>* uses) {
 
   // (C2) + (C3) Find the minimal 'set cover' for all symbol uses.
   const set<string> desired_set_cover = internal::CalculateMinimalIncludes(
-      direct_includes(), associated_direct_includes, uses);
+      quoted_file_, direct_includes(), associated_direct_includes, uses);
 
   // (C4) Remove .cc files from desired-includes unless they're in actual-inc.
   for (const string& header_name : desired_set_cover) {
@@ -1508,7 +1586,8 @@ void IwyuFileInfo::CalculateIwyuViolations(vector<OneUse>* uses) {
           &use, effective_direct_includes, effective_desired_includes,
           AssociatedFileEntries());
     } else {
-      internal::CalculateIwyuForFullUse(&use, effective_direct_includes);
+      internal::CalculateIwyuForFullUse(
+          &use, effective_direct_includes, quoted_file_);
     }
   }
 }
