@@ -400,6 +400,11 @@ void IwyuPreprocessorInfo::MaybeProtectInclude(
     protect_reason = "pragma_keep";
     FileInfoFor(includer)->ReportKnownDesiredFile(includee);
 
+  } else if (ShouldKeepIncludeFor(includee)) {
+    // The command line version of pragma keep.
+    protect_reason = "--keep";
+    FileInfoFor(includer)->ReportKnownDesiredFile(includee);
+
   } else if (LineHasText(includer_loc, "// IWYU pragma: export") ||
              LineHasText(includer_loc, "/* IWYU pragma: export") ||
              HasOpenBeginExports(includer)) {
@@ -609,24 +614,6 @@ void IwyuPreprocessorInfo::MacroDefined(const Token& id,
   }
 }
 
-void IwyuPreprocessorInfo::If(SourceLocation loc, SourceRange condition_range,
-                              ConditionValueKind condition_value) {
-  ERRSYM(GetFileEntry(condition_range.getBegin()))
-      << " [ #if         ] "
-      << PrintableSourceRange(condition_range) << "\n";
-  CheckIfOrElif(condition_range);
-}
-
-void IwyuPreprocessorInfo::Elif(SourceLocation loc,
-                                SourceRange condition_range,
-                                ConditionValueKind condition_value,
-                                SourceLocation if_loc) {
-  ERRSYM(GetFileEntry(condition_range.getBegin()))
-      << " [ #elif       ] "
-      << PrintableSourceRange(condition_range) << "\n";
-  CheckIfOrElif(condition_range);
-}
-
 void IwyuPreprocessorInfo::Ifdef(SourceLocation loc,
                                  const Token& id,
                                  const MacroDefinition& /*definition*/) {
@@ -645,6 +632,18 @@ void IwyuPreprocessorInfo::Ifndef(SourceLocation loc,
   FindAndReportMacroUse(GetName(id), id.getLocation());
 }
 
+// Clang will give a MacroExpands() callback for all macro-tokens
+// used inside an #if or #elif, *except* macro-tokens used within a
+// 'defined' operator. They produce a Defined() callback.
+void IwyuPreprocessorInfo::Defined(const Token& id,
+                                   const MacroDefinition& /*definition*/,
+                                   SourceRange /*range*/) {
+  ERRSYM(GetFileEntry(id.getLocation()))
+      << "[ #if defined ] " << PrintableLoc(id.getLocation())
+      << ": " << GetName(id) << "\n";
+  FindAndReportMacroUse(GetName(id), id.getLocation());
+}
+
 void IwyuPreprocessorInfo::InclusionDirective(
     SourceLocation hash_loc,
     const Token& include_token,
@@ -825,20 +824,6 @@ void IwyuPreprocessorInfo::FindAndReportMacroUse(const string& name,
   }
 }
 
-// Clang will give an OnExpandMacro() callback for all macro-tokens
-// used inside an #if or #elif, *except* macro-tokens used within a
-// 'define': for '#if FOO || defined(BAR)', clang calls
-// OnExpandMacro() for FOO, but not for BAR (since macros within
-// defined() aren't expanded).  We catch BAR-type uses here.
-void IwyuPreprocessorInfo::CheckIfOrElif(SourceRange range) {
-  const vector<Token> defined_args =
-      FindArgumentsToDefined(range, DefaultDataGetter());  // in iwyu_lexer.h
-  for (const Token& token : defined_args) {
-    FindAndReportMacroUse(GetTokenText(token, DefaultDataGetter()),
-                          token.getLocation());
-  }
-}
-
 //------------------------------------------------------------
 // Post-processing functions (done after all source is read).
 
@@ -900,8 +885,7 @@ void IwyuPreprocessorInfo::PopulateIntendsToProvideMap() {
     }
   }
   // Ugh, we can have two files with the same name, using
-  // #include-next (e.g. /usr/include/c++/vector and
-  // third_party/gcc3/vector).  Merge them.
+  // #include-next.  Merge them.
   for (const auto& fileinfo : iwyu_file_info_map_) {
     const FileEntry* file = fileinfo.first;
     // See if a round-trip to string and back ends up at a different file.
