@@ -102,15 +102,12 @@ TEST(GetCanonicalName, MapsInternalToPublic) {
 
 TEST(IsSystemIncludeFile, Basic) {
   EXPECT_FALSE(IsSystemIncludeFile("foo.h"));
-  EXPECT_FALSE(IsSystemIncludeFile("third_party/ICU/icu.h"));
   EXPECT_TRUE(IsSystemIncludeFile("/usr/include/string.h"));
   EXPECT_TRUE(IsSystemIncludeFile("/usr/include/c++/4.3/bits/stl_vector.h"));
 }
 
 TEST(ConvertToQuotedInclude, Basic) {
   EXPECT_EQ("\"foo.h\"", ConvertToQuotedInclude("foo.h"));
-  EXPECT_EQ("\"third_party/ICU/icu.h\"",
-            ConvertToQuotedInclude("third_party/ICU/icu.h"));
   EXPECT_EQ("<string.h>", ConvertToQuotedInclude("/usr/include/string.h"));
   EXPECT_EQ("<bits/stl_vector.h>",
             ConvertToQuotedInclude("/usr/include/c++/4.3/bits/stl_vector.h"));
@@ -208,10 +205,6 @@ TEST(GetCandidateHeadersForFilepath, C) {
   EXPECT_VECTOR_STREQ(
       p.GetCandidateHeadersForFilepath("/usr/include/bits/dlfcn.h"),
       "<dlfcn.h>");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/grte/v2/release/include/"
-                                       "bits/mathcalls.h"),
-      "<math.h>", "<cmath>");
   EXPECT_VECTOR_STREQ(
       p.GetCandidateHeadersForFilepath("/usr/grte/v1/include/assert.h"),
       "<assert.h>", "<cassert>");
@@ -226,95 +219,6 @@ TEST(GetCandidateHeadersForFilepath, CXX) {
   EXPECT_VECTOR_STREQ(
       p.GetCandidateHeadersForFilepath("/usr/include/c++/4.2/bits/allocator.h"),
       "<memory>");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath(
-          "third_party/llvm/crosstool/gcc-4.4.0-glibc-2.3.6-grte/x86/"
-          "include/c++/4.4.0/backward/hash_fun.h"),
-      "<hash_map>", "<hash_set>");
-}
-
-TEST(IsThirdPartyFile, ReturnsFalseForGoogleFile) {
-  EXPECT_FALSE(IsThirdPartyFile("\"foo/bar.h\""));
-  EXPECT_FALSE(IsThirdPartyFile("\"foo/third_party/bar.cc\""));
-}
-
-TEST(IsThirdPartyFile, ReturnsFalseForGoogleFileInThirdParty) {
-  EXPECT_FALSE(IsThirdPartyFile("\"third_party/car/car.h\""));
-  EXPECT_FALSE(IsThirdPartyFile("\"third_party/gtest/a.h\""));
-  EXPECT_FALSE(IsThirdPartyFile("\"third_party/gmock/b.h\""));
-}
-
-TEST(IsThirdPartyFile, ReturnsTrueForNonGoogleFileInThirdParty) {
-  EXPECT_TRUE(IsThirdPartyFile("\"third_party/tr1/tuple\""));
-  EXPECT_TRUE(IsThirdPartyFile("\"third_party/foo/bar.h\""));
-}
-
-TEST(GetCandidateHeadersForFilepath, ThirdParty) {
-  IncludePicker p;
-  p.AddDirectInclude("a.h", "third_party/dynamic_annotations/d.h", "");
-  p.AddDirectInclude("b.h", "third_party/dynamic_annotations/a/b/c.h", "");
-  p.AddDirectInclude("c.h", "third_party/python_runtime/includes/py.h", "");
-  p.AddDirectInclude("d.h", "third_party/isu/include/unicode/udraft.h", "");
-  p.AddDirectInclude("e.h", "third_party/isu/include/unicode/ukeep.h", "");
-  p.FinalizeAddedIncludes();
-
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/dynamic_annotations/d.h"),
-      "\"base/dynamic_annotations.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath(
-          "third_party/dynamic_annotations/a/b/c.h"),
-      "\"base/dynamic_annotations.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/python_runtime/includes/py.h"),
-      "<Python.h>");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath(
-          "third_party/icu/include/unicode/udraft.h"),
-      "\"third_party/icu/include/unicode/utypes.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath(
-          "third_party/icu/include/unicode/ukeep.h"),
-      "\"third_party/icu/include/unicode/ukeep.h\"");
-}
-
-TEST(GetCandidateHeadersForFilepath, ThirdPartyCycle) {
-  IncludePicker p;
-  // We should ignore the cycle here.
-  p.AddDirectInclude("myapp.h", "third_party/a.h", "");
-  p.AddDirectInclude("third_party/a.h", "third_party/b.h", "");
-  p.AddDirectInclude("third_party/b.h", "third_party/c.h", "");
-  p.AddDirectInclude("third_party/c.h", "third_party/a.h", "");  // cycle!
-  p.FinalizeAddedIncludes();
-
-  // We ignore the cycle, so the includes look like a -> b -> c.  In
-  // each case, a.h is the only public header file in the bunch; the
-  // rest are private because they're only #included from other
-  // third_party files.
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/a.h"),
-      "\"third_party/a.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/b.h"),
-      "\"third_party/a.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/c.h"),
-      "\"third_party/a.h\"");
-}
-
-TEST(GetCandidateHeadersForFilepath, RegexOverlap) {
-  IncludePicker p;
-  // It's ok if a header is specified in both a regex and non-regex rule.
-  // For regexes to work, we need to have actually seen the includes.
-  p.AddDirectInclude("a.h", "third_party/dynamic_annotations/d.h", "");
-  p.AddMapping("\"third_party/dynamic_annotations/d.h\"",
-               "\"third_party/dynamic_annotations/public.h\"");
-  p.MarkIncludeAsPrivate("\"third_party/dynamic_annotations/d.h\"");
-  p.FinalizeAddedIncludes();
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/dynamic_annotations/d.h"),
-      "\"third_party/dynamic_annotations/public.h\"",
-      "\"base/dynamic_annotations.h\"");
 }
 
 TEST(GetCandidateHeadersForFilepath, NoIdentityRegex) {
@@ -336,105 +240,12 @@ TEST(GetCandidateHeadersForFilepath, NoIdentityRegex) {
       "\"mydir/include.h\"");
 }
 
-TEST(GetCandidateHeadersForFilepath, ImplicitThirdPartyMapping) {
-  IncludePicker p;
-  p.AddDirectInclude("third_party/public.h", "third_party/private1.h", "");
-  p.AddDirectInclude("third_party/public.h", "third_party/private2.h", "");
-  p.AddDirectInclude("third_party/private1.h", "third_party/private11.h", "");
-  p.AddDirectInclude("third_party/public.h", "third_party/other_public.h", "");
-  p.AddDirectInclude("third_party/other_public.h", "third_party/oprivate.h",
-                     "");
-  p.AddDirectInclude("my_app.h", "third_party/public.h", "");
-  p.AddDirectInclude("my_app.h", "third_party/other_public.h", "");
-  p.FinalizeAddedIncludes();
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/public.h"),
-      "\"third_party/public.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/private1.h"),
-      "\"third_party/public.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/private2.h"),
-      "\"third_party/public.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/private11.h"),
-      "\"third_party/public.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/other_public.h"),
-      "\"third_party/other_public.h\"");
-  // Shouldn't have third_party/public.h here, even though it indirectly
-  // includes oprivate.h, because other_public is in between and is itself
-  // considered a public include (since it is #included from my_app.h).
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/oprivate.h"),
-      "\"third_party/other_public.h\"");
-}
-
-TEST(GetCandidateHeadersForFilepath, TreatsGTestAsNonThirdParty) {
-  IncludePicker p;
-  p.AddDirectInclude("foo/foo.cc", "testing/base/public/gunit.h", "");
-  p.AddDirectInclude("testing/base/public/gunit.h",
-                     "third_party/gtest/include/gtest/gtest.h", "");
-  p.FinalizeAddedIncludes();
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/gtest/include/gtest/gtest.h"),
-      "\"third_party/gtest/include/gtest/gtest.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("testing/base/public/gunit.h"),
-      "\"testing/base/public/gunit.h\"");
-}
-
-TEST(GetCandidateHeadersForFilepath, ExplicitThirdPartyMapping) {
-  IncludePicker p;
-  // These are controlled by third_party_include_map, not by
-  // AddImplicitThirdPartyMappings().
-  p.AddDirectInclude("my_app.h", "third_party/dynamic_annotations/public.h",
-                     "");
-  p.AddDirectInclude("third_party/dynamic_annotations/public.h",
-                     "third_party/dynamic_annotations/private.h", "");
-  p.AddDirectInclude("my_app.h", "third_party/icu/include/unicode/umachine.h",
-                     "");
-  p.FinalizeAddedIncludes();
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath(
-          "third_party/dynamic_annotations/public.h"),
-      "\"base/dynamic_annotations.h\"");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath(
-          "third_party/icu/include/unicode/umachine.h"),
-      "\"third_party/icu/include/unicode/utypes.h\"");
-}
-
-TEST(GetCandidateHeadersForFilepath, ExplicitVsImplicitThirdPartyMapping) {
-  IncludePicker p;
-  // Here, the includees are all explicitly marked as public.
-  p.AddDirectInclude("my_app.h", "third_party/icu/include/unicode/foo.h", "");
-  p.AddDirectInclude("third_party/icu/include/unicode/foo.h",
-                     "third_party/icu/include/unicode/utypes.h", "");
-  p.AddDirectInclude("third_party/icu/include/unicode/foo.h",
-                     "/usr/include/stdio.h", "");
-  p.FinalizeAddedIncludes();
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("/usr/include/stdio.h"),
-      "<stdio.h>", "<cstdio>");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath(
-          "third_party/icu/include/unicode/utypes.h"),
-      "\"third_party/icu/include/unicode/utypes.h\"",
-      "\"third_party/icu/include/unicode/foo.h\"");
-}
-
 TEST(GetCandidateHeadersForFilepath, NotInAnyMap) {
   IncludePicker p;
   p.FinalizeAddedIncludes();
   EXPECT_VECTOR_STREQ(
       p.GetCandidateHeadersForFilepath("/usr/grte/v1/include/poll.h"),
       "<poll.h>");
-  EXPECT_VECTOR_STREQ(
-      p.GetCandidateHeadersForFilepath("third_party/llvm/crosstool/"
-                                       "gcc-4.4.0-glibc-2.3.6-grte/x86/"
-                                       "include/c++/4.4.0/vector"),
-      "<vector>");
   EXPECT_VECTOR_STREQ(
       p.GetCandidateHeadersForFilepath("././././my/dot.h"),
       "\"my/dot.h\"");
@@ -583,16 +394,6 @@ TEST(HasMapping, IncludeMatchDifferentMaps) {
   EXPECT_TRUE(p.HasMapping("/usr/include/c++/4.2/ios", "base/logging.h"));
 }
 
-TEST(HasMapping, IncludeForThirdParty) {
-  IncludePicker p;
-  // For regexes to work, we need to have actually seen the includes.
-  p.AddDirectInclude("base/dynamic_annotations.h",
-                     "third_party/dynamic_annotations/foo/bar.h", "");
-  p.FinalizeAddedIncludes();
-  EXPECT_TRUE(p.HasMapping("third_party/dynamic_annotations/foo/bar.h",
-                           "base/dynamic_annotations.h"));
-}
-
 }  // namespace
 }  // namespace include_what_you_use
 
