@@ -63,15 +63,18 @@ class OneIwyuTest(unittest.TestCase):
     flags_map = {
       'backwards_includes.cc': [self.CheckAlsoExtension('-d*.h')],
       'badinc.cc': [self.MappingFile('badinc.imp')],
+      'builtins_with_mapping.cc': [self.MappingFile('builtins_with_mapping.imp')],
       'check_also.cc': [self.CheckAlsoExtension('-d1.h')],
       'implicit_ctor.cc': [self.CheckAlsoExtension('-d1.h')],
       'iwyu_stricter_than_cpp.cc': [self.CheckAlsoExtension('-autocast.h'),
                                     self.CheckAlsoExtension('-fnreturn.h'),
                                     self.CheckAlsoExtension('-typedefs.h'),
                                     self.CheckAlsoExtension('-d2.h')],
-      'keep_mapping.cc': [self.CheckAlsoExtension('-public.h'), 
+      'keep_includes.c': ['--keep=tests/c/keep_includes*.h'],
+      'keep_mapping.cc': [self.CheckAlsoExtension('-public.h'),
                           self.MappingFile('keep_mapping.imp')],
       'macro_location.cc': [self.CheckAlsoExtension('-d2.h')],
+      'mapping_to_self.cc': [self.MappingFile('mapping_to_self.imp')],
       'non_transitive_include.cc': [self.CheckAlsoExtension('-d*.h'),
                                     '--transitive_includes_only'],
       'no_h_includes_cc.cc': [self.CheckAlsoExtension('.c')],
@@ -85,6 +88,7 @@ class OneIwyuTest(unittest.TestCase):
       'prefix_header_includes_remove.cc': ['--prefix_header_includes=remove'],
       'prefix_header_operator_new.cc': ['--prefix_header_includes=remove'],
       'quoted_includes_first.cc': ['--pch_in_code', '--quoted_includes_first'],
+      'cxx17ns.cc': ['--cxx17ns'],
     }
     prefix_headers = [self.Include('prefix_header_includes-d1.h'),
                       self.Include('prefix_header_includes-d2.h'),
@@ -104,6 +108,7 @@ class OneIwyuTest(unittest.TestCase):
       'macro_defined_by_includer.cc': [
           '-std=c++11', '-DCOMMAND_LINE_TYPE=double',
           self.Include('macro_defined_by_includer-prefix.h')],
+      'macro_location.cc': ['-Wno-sizeof-pointer-div'],
       'ms_inline_asm.cc': ['-fms-extensions'],
       'prefix_header_attribution.cc': [self.Include('prefix_header_attribution-d1.h')],
       'prefix_header_includes_add.cc': prefix_headers,
@@ -112,6 +117,7 @@ class OneIwyuTest(unittest.TestCase):
       'range_for.cc': ['-std=c++11'],
       'typedef_in_template.cc': ['-std=c++11'],
       'inheriting_ctor.cc': ['-std=c++11'],
+      'cxx17ns.cc': ['-std=c++17'],
     }
     include_map = {
       'alias_template.cc': ['.'],
@@ -121,6 +127,7 @@ class OneIwyuTest(unittest.TestCase):
       'backwards_includes.cc': ['.'],
       'badinc.cc': ['.'],
       'badinc-extradef.cc': ['.'],
+      'builtins_with_mapping.cc': ['.'],
       'funcptrs.cc': ['.'],
       'casts.cc': ['.'],
       'catch.cc': ['.'],
@@ -136,6 +143,7 @@ class OneIwyuTest(unittest.TestCase):
       'double_include.cc': ['.'],
       'elaborated_struct.c': ['.'],
       'elaborated_type.cc': ['.'],
+      'export_nesting.cc': ['.'],
       'external_including_internal.cc': ['.'],
       'forward_declare_in_macro.cc': ['.'],
       'fullinfo_for_templates.cc': ['.'],
@@ -148,10 +156,12 @@ class OneIwyuTest(unittest.TestCase):
       'include_with_using.cc': ['.'],
       'internal/internal_files.cc': ['.'],
       'iwyu_stricter_than_cpp.cc': ['.'],
+      'keep_includes.c': ['.'],
       'keep_mapping.cc': ['.'],
       'lateparsed_template.cc': ['.'],
       'macro_defined_by_includer.cc': ['.'],
       'macro_location.cc': ['.'],
+      'mapping_to_self.cc': ['.'],
       'member_expr.cc': ['.'],
       'multiple_include_paths.cc': ['.'],
       'new_header_path_provided.cc': ['.'],
@@ -191,6 +201,7 @@ class OneIwyuTest(unittest.TestCase):
       'using_aliased_symbol_unused.cc': ['.'],
       'varargs_and_references.cc': ['.'],
       'virtual_tpl_method.cc': ['.'],
+      'cxx17ns.cc': ['.'],
     }
     # Internally, we like it when the paths start with rootdir.
     self._iwyu_flags_map = dict((posixpath.join(self.rootdir, k), v)
