@@ -7,9 +7,9 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_TESTS_PREFIX_HEADER_INCLUDES_I1_H_
-#define DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_TESTS_PREFIX_HEADER_INCLUDES_I1_H_
+#ifndef INCLUDE_WHAT_YOU_USE_TESTS_CXX_PREFIX_HEADER_INCLUDES_I1_H_
+#define INCLUDE_WHAT_YOU_USE_TESTS_CXX_PREFIX_HEADER_INCLUDES_I1_H_
 
 class CommandLineIncludeI1 {};
 
-#endif  // DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_TESTS_PREFIX_HEADER_INCLUDES_I1_H_
+#endif  // INCLUDE_WHAT_YOU_USE_TESTS_CXX_PREFIX_HEADER_INCLUDES_I1_H_
